@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,9 +29,7 @@ BalsaAddressBook::BalsaAddressBook(const QString &filename)
 {
 }
 
-BalsaAddressBook::~BalsaAddressBook()
-{
-}
+BalsaAddressBook::~BalsaAddressBook() = default;
 
 void BalsaAddressBook::importAddressBook()
 {
